#ifndef H_CDW_CDDB
#define H_CDW_CDDB

#ifdef HAVE_LIBMYSQLCLIENT
#include <mysql/mysql.h>

void cddb_window();
void insert_disk(char *disk, char *cd_num, char *type);
int add_to_dic();
MYSQL_RES* query_type(char *type);
MYSQL_RES* query_content(char *type, char *disk, char *dir);
MYSQL_RES* query_disk(char *cdname, int no, char *type);
MYSQL_RES* search_content(char *file, char *type, char *disk, char *dir)

#endif /* #ifdef HAVE_LIBMYSQLCLIENT */



#ifdef HAVE_LIBSQLITE
#include <sqlite.h>

void cddb_window();
void insert_disk(char *disk, char *cd_num, char *type);
int add_to_dic();
/*SQLITE_RES* query_type(char *type);
SQLITE_RES* query_content(char *type, char *disk, char *dir);
SQLITE_RES* query_disk(char *cdname, int no, char *type);
SQLITE_RES* search_content(char *file, char *type, char *disk, char *dir)*/
#endif /* #ifdef HAVE_LIBSQLITE */

#endif /* #ifndef H_CDW_CDDB */
